@@ -32,6 +32,21 @@ class Database(TinyDB):
             })
         return ShowId(show.id)
 
+    def add_episode(self, show_id: ShowId, episode: TVMazeEpisode) -> EpisodeId:
+        """Helper method used in tests"""
+        self.table(EPISODE).insert({
+            'id': episode.id,
+            'show_id': show_id,
+            'season': episode.season,
+            'number': episode.number,
+            'name': episode.name,
+            'airdate': episode.airdate,
+            'runtime': episode.runtime,
+            'watched': ''
+        })
+        return EpisodeId(episode.id)
+
+
     def get_shows(self) -> List[Show]:
         """Returns list of all addded shows"""
         return cast(List[Show], self.table(SHOW).all())
@@ -63,7 +78,7 @@ class Database(TinyDB):
         return cast(List[int], self.table(EPISODE).remove(EpisodeQ.id == episode_id))
 
     def sync_episodes(self, show_id: ShowId, episodes: List[TVMazeEpisode], on_insert: Union[Callable[[TVMazeEpisode], None], None]=None, on_update: Union[Callable[[TVMazeEpisode], None], None]=None) -> None:
-        """Updates episodes fro API reuslts"""
+        """Updates episodes from API reuslts"""
         existing_episodes = self.get_episodes(show_id)
         queue = []
         for episode in episodes:
@@ -113,8 +128,8 @@ class Database(TinyDB):
     def get_unwatched(self) -> List[DecoratedEpisode]:
         """Returns all aired episodes which are not watched yet"""
         EpisodeQ = Query()
-        return self.decorate_episodes(
-            sorted(self.table(EPISODE).search(((EpisodeQ.watched == '') & (EpisodeQ.airdate <= datetime.utcnow().isoformat()))), key=lambda episode: episode['airdate'] or ''))
+        episodes = cast(List[Episode], sorted(self.table(EPISODE).search(((EpisodeQ.watched == '') & (EpisodeQ.airdate <= datetime.utcnow().isoformat()))), key=lambda episode: episode['airdate'] or ''))
+        return self.decorate_episodes(episodes)
 
     def update_watched_show(self, show_id: ShowId, watched: bool) -> None:
         """Updates all episodes of a show as watched now"""
@@ -135,18 +150,19 @@ class Database(TinyDB):
     def last_seen(self, show_id: ShowId, season: int, number: int) -> int:
         """Updates all show episodes as seen up to season and number"""
         episodes = self.get_episodes(show_id)
-        eids = []
+        episode_ids = []
         for episode in episodes:
             if episode['season'] > season:
                 continue
-            if episode['season'] < season or (episode['season'] == season and episode['number'] < number):
-                eids.append(episode['id'])
+            if episode['season'] < season or (episode['season'] == season and episode['number'] <= number):
+                episode_ids.append(episode['id'])
                 continue
         watched_value = datetime.utcnow().isoformat()
+        EpisodeQ = Query()
         self.table(EPISODE).update({
             'watched': watched_value
-        }, eids=eids)
-        return len(eids)
+        }, EpisodeQ.id.one_of(episode_ids))
+        return len(episode_ids)
 
     def get_next_unwatched(self, show_id: ShowId)-> Union[Episode, None]:
         """Returns the first episode from a show that has not been watched"""
@@ -167,9 +183,9 @@ class Database(TinyDB):
     def aired_unseen_between(self, from_date: date, to_date: date) -> List[DecoratedEpisode]:
         """Returns list of episodes that were aired but have not been seen between two dates"""
         EpisodeQ = Query()
-        episodes = self.table(EPISODE).search(
+        episodes = cast(List[Episode], self.table(EPISODE).search(
             (EpisodeQ.airdate.test(_test_between, from_date, to_date)) &
-            (EpisodeQ.watched == ''))
+            (EpisodeQ.watched == '')))
         return self.decorate_episodes(episodes)
 
     def decorate_episodes(self, episodes: List[Episode]) -> List[DecoratedEpisode]:
@@ -199,6 +215,29 @@ class Database(TinyDB):
         EpisodeQ = Query()
         return cast(List[Episode], self.table(EPISODE).search(EpisodeQ.watched != ''))
 
+    def get_completed_shows(self) -> List[Show]:
+        """Returns all shows that have been completed"""
+        completed: Set[ShowId] = set()
+        partial: Set[ShowId] = set()
+        last_watched: Dict[ShowId, string] = {}
+        for episode in self.table(EPISODE):
+            show_id = episode['show_id']
+            if show_id in partial:
+                continue
+            if episode['watched'] == '':
+                partial.add(show_id)
+                if show_id in completed:
+                    completed.remove(show_id)
+                continue
+            if (not show_id in last_watched) or (last_watched[show_id] < episode['watched']):
+                last_watched[show_id] = episode['watched'];
+
+            completed.add(show_id)
+        sorted_watched = sorted(last_watched, key=last_watched.get)
+        ShowQ = Query()
+        shows = cast(List[Show], self.table(SHOW).search(ShowQ.id.one_of(completed)))
+        return sorted(shows, key=lambda row: sorted_watched.index(row['id']))
+
 
 def getDirectWriteDB(file_name: str) -> Database:
     """Returns database instance with direct interface"""
